Restretto: REST resources/endpoints testing tool
================================================

Restretto is a simple tool for testing REST API servers using scenarios
written in YAML files


Features
--------

See examples/features.yml
